from setuptools import find_packages,setup
setup(
    name = 'softinfo',
    version = '0.1',
    packages = find_packages(),
    author="523144419",
    author_email="523144419@qq.com",
    description="For scan software info package",
    url="https://github.com/523144419/autoScan4CMDB",
)
